@@ -1,5 +1,5 @@
 use crypto_market_type::MarketType;
-use crypto_rest_client::fetch_l2_snapshot;
+use crypto_rest_client::{fetch_l2_snapshot, fetch_open_interest};
 use serde_json::Value;
 use std::collections::HashMap;
 use test_case::test_case;
@@ -13,3 +13,12 @@ fn test_l2_snapshot(market_type: MarketType, symbol: &str) {
     assert!(obj.get("asks").unwrap().as_array().unwrap().len() > 0);
     assert!(obj.get("bids").unwrap().as_array().unwrap().len() > 0);
 }
+
+#[test_case(MarketType::InverseSwap, "btcusd")]
+#[test_case(MarketType::LinearSwap, "cmt_btcusdt")]
+fn test_open_interest(market_type: MarketType, symbol: &str) {
+    let text = fetch_open_interest("bitget", market_type, Some(symbol)).unwrap();
+    let obj = serde_json::from_str::<HashMap<String, Value>>(&text).unwrap();
+
+    assert!(obj.contains_key("amount"));
+}
