@@ -1,7 +1,7 @@
 use std::collections::HashMap;
 
 use crypto_market_type::MarketType;
-use crypto_rest_client::fetch_l2_snapshot;
+use crypto_rest_client::{fetch_l2_snapshot, fetch_open_interest};
 use serde_json::Value;
 use test_case::test_case;
 
@@ -19,3 +19,11 @@ fn test_l2_snapshot(market_type: MarketType, symbol: &str) {
     assert!(result.get("asks").unwrap().is_array());
     assert!(result.get("bids").unwrap().is_array())
 }
+
+#[test]
+fn test_open_interest() {
+    let text = fetch_open_interest("ftx", MarketType::Unknown, None).unwrap();
+    let obj = serde_json::from_str::<HashMap<String, Value>>(&text).unwrap();
+    let result = obj.get("result").unwrap().as_array().unwrap();
+    assert!(!result.is_empty())
+}
